@@ -3,6 +3,8 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -498,7 +500,7 @@ unicode2dos(uc)
  */
 __private_extern__ int
 dos2unicodefn(dn, un, lower)
-	u_char dn[11];
+	u_char dn[SHORT_NAME_LEN];
 	u_int16_t *un;
 	int lower;
 {
@@ -580,7 +582,7 @@ dos2unicodefn(dn, un, lower)
  * names only if all characters are pure ASCII.
  */
 __private_extern__ int
-unicode2dosfn(const u_int16_t *un, u_char dn[12], int unlen, u_int gen, u_int8_t *lower_case)
+unicode2dosfn(const u_int16_t *un, u_char dn[SHORT_NAME_LEN], int unlen, u_int gen, u_int8_t *lower_case)
 {
 	int i, j, l;
 	int conv = 1;
@@ -595,9 +597,8 @@ unicode2dosfn(const u_int16_t *un, u_char dn[12], int unlen, u_int gen, u_int8_t
 	 * Fill the dos filename string with blanks. These are DOS's pad
 	 * characters.
 	 */
-	for (i = 0; i < 11; i++)
+	for (i = 0; i < SHORT_NAME_LEN; i++)
 		dn[i] = ' ';
-	dn[11] = 0;
 
 	/*
 	 * The filenames "." and ".." are handled specially, since they
@@ -648,7 +649,7 @@ unicode2dosfn(const u_int16_t *un, u_char dn[12], int unlen, u_int gen, u_int8_t
 			l = dp1 - dp;
 		else
 			l = unlen - (dp - un);
-		for (case_flags = i = 0, j = 8; i < l && j < 11; i++, j++) {
+		for (case_flags = i = 0, j = 8; i < l && j < SHORT_NAME_LEN; i++, j++) {
 			c = dp[i];
 			if (c < 0x80)
 				case_flags |= ascii_case[c];
@@ -1088,7 +1089,7 @@ winChksum(name)
 	int i;
 	u_int8_t s;
 
-	for (s = 0, i = 11; --i >= 0; s += *name++)
+	for (s = 0, i = SHORT_NAME_LEN; --i >= 0; s += *name++)
 		s = (s << 7)|(s >> 1);
 	return s;
 }
