@@ -3,6 +3,8 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -80,6 +82,7 @@
 #include <sys/vnode.h>
 #include <sys/ubc.h>
 #include <sys/namei.h>
+#include <mach/boolean.h>
 
 #include "bpb.h"
 #include "msdosfsmount.h"
@@ -229,7 +232,6 @@ deget(pmp, dirclust, diroffset, dvp, cnp, depp, context)
 	struct timeval tv;
 	struct vnode_fsparam vfsp;
 	enum vtype vtype;
-	vnode_t vp;
 
 	/*
 	 * On FAT32 filesystems, root is a (more or less) normal
@@ -404,16 +406,15 @@ deget(pmp, dirclust, diroffset, dvp, cnp, depp, context)
 	/* vfsp.vnfs_markroot was set or cleared above */
 	vfsp.vnfs_marksystem = 0;	/* msdosfs has no "system" vnodes */
 	
-	error = vnode_create(VNCREATE_FLAVOR, VCREATESIZE, &vfsp, &vp);
+	error = vnode_create(VNCREATE_FLAVOR, VCREATESIZE, &vfsp, &new_dep->de_vnode);
 	if (error)
 		goto fail;
 
 	/*
-	 * Make the denode reference the new vnode, and
-	 * take a reference on it (on behalf of the denode).
+	 * Take an "fs"  reference on the new vnode on
+	 * behalf of the denode.
 	 */
-	new_dep->de_vnode = vp;
-	vnode_addfsref(vp);
+	vnode_addfsref(new_dep->de_vnode);
 	
 	/*
 	 * Return it.  We're done.
@@ -467,15 +468,19 @@ deupdat(dep, waitfor, context)
 	error = readde(dep, &bp, &dirp, context);
 	if (error)
 		return (error);
-        if (vnode_isvroot(DETOV(dep)))
-            DE_EXTERNALIZE_ROOT(dirp, dep);
-        else
-            DE_EXTERNALIZE(dirp, dep);
+		
+	if (vnode_isvroot(DETOV(dep)))
+		DE_EXTERNALIZE_ROOT(dirp, dep);
+	else
+		DE_EXTERNALIZE(dirp, dep);
 	return ((int)buf_bdwrite(bp));
 }
 
 /*
  * Truncate the file described by dep to the length specified by length.
+ *
+ * NOTE: This function takes care of updating dep->de_FileSize and calling
+ * ubc_setsize with new length.
  */
 __private_extern__ int
 detrunc(dep, length, flags, context)
@@ -488,10 +493,7 @@ detrunc(dep, length, flags, context)
     int allerror;
     u_long eofentry;
     u_long chaintofree;
-    daddr64_t bn;
-    int boff;
     int isadir = dep->de_Attributes & ATTR_DIRECTORY;
-    struct buf *bp;
     struct msdosfsmount *pmp = dep->de_pmp;
     vnode_t vp = DETOV(dep);
 
